// Code to synch FE startup with 1PPS signal on last channel
// of first ADC module.
// Clocks are already running, so can't enable all ADC cards
// at once as some may trigger on one clock and one or more
// on the next clock, leaving them out of sync with each other.
// So idea is to enable one ADC to find the clock and then
// enable all cards in time frame before next clock.

int sync2pps_signal(int onePpsTime,  adcInfo_t* padcinfo , int cpuClock[])
{
    int status;
    int onePps;
    int pps_wait = 0;
    int sync = SYNC_SRC_1PPS;
    unsigned long nanotime = 100000;

    // Enable only the 1st ADC
    gsc16ai64EnableModule( 0 );
    // Wait for DMA done to indicate an ADC clock just occurred
    status = plx9056_wait_dma_done( 0, 1, 100 );
    // Found a clock so now enable all cards
    gsc16ai64Enable( &cdsPciModules );
    gsc18ai32Enable( &cdsPciModules );
    gsc18ai64Enable( &cdsPciModules );

    // Now search for the 1PPS sync pulse
    // on last channel of 1st ADC
    do
    {
        status = iop_adc_read( padcinfo, cpuClock );
        onePps = dWord[ ADC_ONEPPS_BRD ][ ADC_DUOTONE_CHAN ][ 0 ];
        pps_wait++;
    } while ( onePps < ONE_PPS_THRESH && pps_wait < onePpsTime );
    // If 1PPS signal not found, use internal clock
    if ( pps_wait >= onePpsTime )
    {
        // Sync21PPS failed, so default to no sync
        sync = SYNC_SRC_NONE;
        pps_wait = 0;
        // Now search for the start of 1sec from internal clock
        do
        {
            status = iop_adc_read( padcinfo, cpuClock );
            nanotime = current_nanosecond( );
            pps_wait++;
        } while ( nanotime < 50000 && pps_wait < onePpsTime );
    }
    // Enable all DAC cards
    gsc16ao16Enable( &cdsPciModules );
    gsc18ao8Enable( &cdsPciModules );
    gsc20ao8Enable( &cdsPciModules );
    return sync;
}
