//
// Created by erik.vonreis on 4/27/21.
//

#include <fcntl.h>
#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include "shared_memory.h"
#include "shmem_all.h"
#include "drv/shmem.h"

// AWG data shared memory

volatile AWG_DATA* shmemAwgData = NULL;

int
OpenAwgDataSharedMemory( const char* model_name )
{
    char         buff[ 256 ];
    shmem_handle handle = NULL;

    strncpy( buff, model_name, sizeof( buff ) );
    buff[ sizeof( buff ) - 1 ] = 0;
    strncat( buff, SHMEM_AWG_SUFFIX, sizeof( buff ) - 1 );
    buff[ sizeof( buff ) - 1 ] = 0;
    handle = shmem_open( buff, SHMEM_AWG_SIZE_MB );
    shmemAwgData = shmem_mapping( handle );
    AWG_DATA_INIT( shmemAwgData );
    return ( shmemAwgData != NULL ) ? -1 : 0;
}

// IO from IOP shared memory
volatile IO_MEM_DATA* ioMemData = NULL;

// Pointers into the shared memory for the cycle and time (coming from the IOP
// (e.g. x00)) these are just convenient pointers into some part of ioMemData.
volatile unsigned int* ioMemDataCycle = NULL;
volatile unsigned int* ioMemDataGPS = NULL;
volatile unsigned int* ioMemDataRate_sps = NULL;

int
OpenIoMemSharedMemory( )
{
    volatile void* iomem_base = NULL;
    shmem_handle   handle = NULL;

    handle = shmem_open( SHMEM_IOMEM_NAME, SHMEM_IOMEM_SIZE_MB );
    iomem_base = shmem_mapping( handle );

    ioMemData = (volatile IO_MEM_DATA*)( iomem_base + IO_MEM_DATA_OFFSET );

    return ( ioMemData != NULL ) ? -1 : 0;
}


volatile TESTPOINT_CFG * shmemTestpointCfg = NULL;

int
OpenTestpointCfgSharedMemory(const char *model_name)
{
    char            buff[256];
    shmem_handle    handle = NULL;

    strncpy( buff, model_name, sizeof( buff));
    buff[ sizeof(buff) - 1] = 0;
    strncat( buff, SHMEM_TESTPOINT_SUFFIX, sizeof(buff) - 1);
    buff[ sizeof(buff) - 1] = 0;
    handle = shmem_open(buff, SHMEM_TESTPOINT_SIZE_MB );
    shmemTestpointCfg = shmem_mapping( handle );
    TESTPOINT_CFG_INIT(shmemTestpointCfg);
    return ( shmemTestpointCfg != NULL ) ? -1 : 0;
}