#include "gsc_adc_common.h"
// *****************************************************************************
/// \brief Routine reads number of samples in ADC FIFO.
/// @param[in] numAdc The ID number of the ADC module to read.
/// @return The number of samples presently in the ADC FIFO.
// *****************************************************************************
int
gscCheckAdcBuffer( int numAdc )
{
    int dataCount;

    dataCount = _adcPtr[ numAdc ]->BUF_SIZE;
    return ( dataCount );
}

void
gscDisableAdcClk( CDS_HARDWARE* pHardware, int card )
{
    int ii;
    int fc, lc;

    if ( card == GSAI_ALL_CARDS )
    {
        fc = 0;
        lc = pHardware->adcCount;
    }
    else
    {
        fc = card;
        lc = card + 1;
    }
    for ( ii = fc; ii < lc; ii++ )
    {
        if ( pHardware->adcType[ ii ] == GSC_16AI64SSA )
            _adcPtr[ ii ]->BCR &= ~( GSAI_ENABLE_X_SYNC );
        if ( pHardware->adcType[ ii ] == GSC_18AI32SSC1M )
            _adcPtr[ ii ]->SSC &= ~( GSAI_ENABLE_CLOCK );
        if ( pHardware->adcType[ ii ] == GSC_18AI64SSC )
            _adcPtr[ ii ]->SSC &= ~( GSAI_CLOCK_ENABLE );
        _adcPtr[ ii ]->IDBC = ( GSAI_CLEAR_BUFFER | GSAI_THRESHOLD );
    }
}

// *****************************************************************************
/// \brief Function clears ADC buffer and starts acquisition via external clock.
///< Also sets up ADC for Demand DMA mode and set GO bit in DMA Mode Register.
///< NOTE: In normal operation, this code should only be called while the clocks
///< from the timing receiver are turned OFF ie during initialization process.
/// @param[in] adcCount Total number of ADC modules to start DMA.
// *****************************************************************************
int
gscEnableAdcModule( CDS_HARDWARE* pHardware, int card, int dmamode )
{
    int ii;
    int fc, lc;

    if ( card == GSAI_ALL_CARDS )
    {
        fc = 0;
        lc = pHardware->adcCount;
    }
    else
    {
        fc = card;
        lc = card + 1;
    }

    for ( ii = fc; ii < lc; ii++ )
    {
        if ( dmamode )
        {
            /// Enable demand DMA mode ie auto DMA data to computer memory when
            ///< GSAI_THRESHOLD data points in ADC FIFO.
            if ( pHardware->adcType[ ii ] == GSC_16AI64SSA )
                _adcPtr[ ii ]->BCR &= ~( GSAI_DMA_DEMAND_MODE );
            /// Set DMA mode and direction in PLX controller chip on module.
            /// Enable DMA
            plx9056_dma_enable( ii );
        }
        /// Clear the FIFO and set demand DMA to start after all 32 channels
        /// have 1 sample
        _adcPtr[ ii ]->IDBC = ( GSAI_CLEAR_BUFFER | GSAI_THRESHOLD );
        if ( pHardware->adcType[ ii ] == GSC_18AI32SSC1M )
        {
            /// Enable 18bit data
            _adcPtr[ ii ]->IDBC |= GSAI_18BIT_DATA;
            /// Enable sync via external clock input.
            _adcPtr[ ii ]->SSC |= GSAI_ENABLE_CLOCK;
        }
        if ( pHardware->adcType[ ii ] == GSC_16AI64SSA )
            /// Enable sync via external clock input.
            _adcPtr[ ii ]->BCR |= GSAI_ENABLE_X_SYNC;
        if ( pHardware->adcType[ ii ] == GSC_18AI64SSC )
            /// Enable sync via external clock input.
            _adcPtr[ ii ]->SSC |= GSAI_CLOCK_ENABLE;
    }
    return ( 0 );
}
