#include "plx_9056.h"

// *****************************************************************************
/// \brief Function checks status of DMA DONE bit for an ADC module.
///     @param[in] module ID of ADC board to read.
/// @return Status of ADC module DMA DONE bit (0=not complete, 1= complete)
// *****************************************************************************
int
plx9056_check_dma_done( int module )
{
    // Return 0 if DMA not complete
    if ( ( adcDma[ module ]->DMA_CSR & PLX_DMA_DONE ) == 0 )
        return ( 0 );
    // Return 1 if DMA is complete
    else
        return ( 1 );
}

// *****************************************************************************
/// \brief Function if DMA from ADC module is complete.
///< Code will remain in loop until DMA is complete.
///     @param[in] module ID of ADC board to read.
/// @param[out] data Status of DMA DONE bit.
/// @return ADC DMA Status (0=not complete, 16=complete
/// Note: This function not presently used.
// *****************************************************************************
int
plx9056_wait_dma_done( int module, int timeinterval, int time2wait)
{
    int ii = 0;
    do
    {
        ii++;
        udelay( timeinterval );
    } while ( ( adcDma[ module ]->DMA_CSR & PLX_DMA_DONE == 0 ) &&
              ( ii < time2wait ) );
    // If DMA did not complete, return error
    if ( ii >= time2wait )
        return -1;
    else
        return 0;
}

void
plx9056_dma_setup( int module, int dma_bytes )
{
    /// Set DMA mode such that completion does not cause interrupt on bus.
    adcDma[ module ]->DMA0_MODE = PLX_DMA_MODE_NO_INTR;
    /// Load PCI address (remapped local memory) to which data is to be
    /// delivered.
    adcDma[ module ]->DMA0_PCI_ADD = (int)adc_dma_handle[ module ];
    /// Set the PCI address of board where data will be transferred from.
    adcDma[ module ]->DMA0_LOC_ADD = PLX_DMA_LOCAL_ADDR;
    /// Set the number of bytes to be transferred.
    adcDma[ module ]->DMA0_BTC = dma_bytes;
    /// Set the DMA direction ie ADC to computer memory.
    adcDma[ module ]->DMA0_DESC = PLX_DMA_TO_PCI;
}

void
plx9056_dma_enable( int module )
{
    /// Set DMA mode and direction in PLX controller chip on module.
    adcDma[ module ]->DMA0_MODE = PLX_DMA_MODE_NO_INTR | 0x1000;
    /// Enable DMA
    adcDma[ module ]->DMA_CSR = PLX_DMA_START;
}

void
plx9056_dma_start( int module )
{
    adcDma[ module ]->DMA_CSR = PLX_DMA_START;
}
